Package: samon
Version: 4.0.2
Type: Package
Date: 2023-10-08
Title: Sensitivity Analysis for Missing Data
Authors@R: c(person("Daniel", "O. Scharfstein", role = c("aut"), email = "dscharf@jhu.edu" ), person("Aidan", "McDermott", role = c("aut", "cre"), email = "amcderm1@jhu.edu")) 
Author: Daniel O. Scharfstein [aut],
  Aidan McDermott [aut, cre]
Maintainer: Aidan McDermott <amcderm1@jhu.edu>
Description: In a clinical trial with repeated measures designs, outcomes are often taken from subjects at fixed time-points.  The focus of the trial may be to compare the mean outcome in two or more groups at some pre-specified time after enrollment. In the presence of missing data auxiliary assumptions are necessary to perform such comparisons.  One commonly employed assumption is the missing at random assumption (MAR).   The 'samon' package allows the user to perform a (parameterized) sensitivity analysis of this assumption.  In particular it can be used to examine the sensitivity of tests in the difference in outcomes to violations of the MAR assumption.  The sensitivity analysis can be performed under two scenarios, a) where the data exhibit a monotone missing data pattern (see the samon() function), and, b) where in addition to a monotone missing data pattern the data exhibit intermittent missing values (see the samonIM() function).
License: GPL-2
Depends: R (>= 2.10)
NeedsCompilation: yes
Packaged: 2023-10-25 22:09:56 UTC; aidanmcdermott
Repository: CRAN
Date/Publication: 2023-10-26 07:10:02 UTC
Built: R 4.3.3; aarch64-apple-darwin20; 2025-01-24 12:19:09 UTC; unix
Archs: samon.so.dSYM
