useDynLib(samon)
importFrom("stats", "aggregate", "quantile", "sd", "t.test", "var", "qnorm")
export(samoneval)
export(samonevalIM)
export(samonIM)
export(samon)
export(samonGen)
export(samonGenIM)
export(samonCombine)
export(samonCombineIM)
export(samonSummary)
export(samonSummaryIM)
export(samonDifferenceSummary)
export(samonDifferenceSummaryIM)
export(samonCrossSummary)
export(samonCrossSummaryIM)
export(samonECompleterStatus)
export(alpha0TableResults)
export(alpha0TableResultsIM)
export(alpha0Tables)
export(alpha0TablesIM)
export(samonTable1)
export(samonTabmat1)
export(samonDataCheck)
